pub enum ReadFirst {
Pin,
Worktree,
}Expand description
Which copy of a walkthrough’s file Review::compute_walkthrough_files
reads first, falling back to the other.
Variants
Pin
The commit the walkthrough was pinned to, for code that was committed.
Worktree
The file on disk, for a walkthrough of uncommitted work.